@@ -1,7 +1,8 @@
 from hglib.error import CommandError
 import client, util, templates
 
-_nullcset = ['-1', '000000000000000000000000000000000000000', '', '', '', '', '']
+_nullcset = ['-1', '000000000000000000000000000000000000000', '', '',
+             '', '', '']
 
 class changectx(object):
     """A changecontext object makes access to data related to a particular
