@@ -103,10 +103,10 @@ def cmdbuilder(name, *args, **kwargs):
     return cmd
 
 class reterrorhandler(object):
-    """
-    This class is meant to be used with rawcommand() error handler argument.
-    It remembers the return value the command returned if it's one of allowed
-    values, which is only 1 if none are given. Otherwise it raises a CommandError.
+    """This class is meant to be used with rawcommand() error handler
+    argument. It remembers the return value the command returned if
+    it's one of allowed values, which is only 1 if none are given.
+    Otherwise it raises a CommandError.
 
     >>> e = reterrorhandler('')
     >>> bool(e)
@@ -115,6 +115,7 @@ class reterrorhandler(object):
     'a'
     >>> bool(e)
     False
+
     """
     def __init__(self, args, allowed=None):
         self.args = args
