@@ -20,7 +20,8 @@ class basetest(unittest.TestCase):
         self.clients = []
         self._oldopen = hglib.client.hgclient.open
         # hglib.open = resultappender(self.clients)(hglib.open)
-        hglib.client.hgclient.open = resultappender(self.clients)(hglib.client.hgclient.open)
+        c = hglib.client.hgclient
+        c.open = resultappender(self.clients)(c.open)
 
         os.mkdir(self._testtmp)
         os.chdir(self._testtmp)
@@ -29,8 +30,8 @@ class basetest(unittest.TestCase):
         self.client = hglib.open()
 
     def tearDown(self):
-        # on Windows we cannot rmtree before closing all instances because of used
-        # files
+        # on Windows we cannot rmtree before closing all instances
+        # because of used files
         hglib.client.hgclient.open = self._oldopen
         for client in self.clients:
             if client.server is not None:
