@@ -7,9 +7,12 @@ class test_annotate(common.basetest):
         self.append('a', 'a\n')
         rev, node1 = self.client.commit('second')
 
-        self.assertEquals(list(self.client.annotate('a')), [('0', 'a'), ('1', 'a')])
-        self.assertEquals(list(self.client.annotate('a', user=True, file=True,
-                          number=True, changeset=True, line=True, verbose=True)),
+        self.assertEquals(list(self.client.annotate('a')), [('0',
+                                                             'a'), ('1', 'a')])
+        self.assertEquals(list(
+            self.client.annotate(
+                'a', user=True, file=True,
+                number=True, changeset=True, line=True, verbose=True)),
                           [('test 0 %s a:1' % node0[:12], 'a'),
                            ('test 1 %s a:2' % node1[:12], 'a')])
 
