@@ -29,7 +29,8 @@ class test_branch(common.basetest):
         self.client.branch('foo')
         self.append('a', 'a')
         self.client.commit('second')
-        self.assertRaises(hglib.error.CommandError, self.client.branch, 'default')
+        self.assertRaises(hglib.error.CommandError,
+                          self.client.branch, 'default')
 
     def test_force(self):
         self.append('a', 'a')
@@ -38,5 +39,6 @@ class test_branch(common.basetest):
         self.append('a', 'a')
         self.client.commit('second')
 
-        self.assertRaises(hglib.error.CommandError, self.client.branch, 'default')
+        self.assertRaises(hglib.error.CommandError,
+                          self.client.branch, 'default')
         self.assertEquals(self.client.branch('default', force=True), 'default')
