@@ -25,3 +25,9 @@ class test_config(common.basetest):
 
         self.assertTrue((os.path.abspath('.hg/hgrc') + ':2',
                          'section', 'key', 'value') in config)
+
+class test_config_arguments(common.basetest):
+    def test_basic(self):
+        client = hglib.open(configs=['diff.unified=5', 'a.b=foo'])
+        self.assertEqual(client.config('a'), [('a', 'b', 'foo')])
+        self.assertEqual(client.config('diff'), [('diff', 'unified', '5')])
