@@ -37,7 +37,8 @@ class test_diff(common.basetest):
  a
 +a
 """ % (node0[:12], node1[:12])
-        self.assertEquals(diff4, self.client.diff(revs=[rev0, rev1], nodates=True))
+        self.assertEquals(diff4, self.client.diff(revs=[rev0, rev1],
+                                                  nodates=True))
 
     def test_basic_plain(self):
         open('.hg/hgrc', 'a').write('[defaults]\ndiff=--git\n')
