@@ -58,7 +58,8 @@ class test_update(common.basetest):
         self.assertEquals(self.client.parents()[0].node, node2)
 
     def test_check_clean(self):
-        self.assertRaises(ValueError, self.client.update, clean=True, check=True)
+        self.assertRaises(ValueError, self.client.update, clean=True,
+                          check=True)
 
     def test_clean(self):
         old = open('a').read()
